from geniusweb.inform.Inform import Inform
from geniusweb.actions.PartyId import PartyId

from geniusweb.references.ProfileRef import ProfileRef
from geniusweb.references.ProtocolRef import ProtocolRef
from geniusweb.references.Parameters import Parameters
from geniusweb.progress.Progress import Progress

class Settings (Inform):
	'''
	Informs a Party about all settings for the upcoming negotiation session. This
	should be sent to a party one time, so that the party knows the situation.
	'''

def __init__(self, id:PartyId , profile:ProfileRef ,protocol:ProtocolRef ,
		progress:Progress ,parameters:Parameters ):
	'''
	@param id         the {@link PartyId} for this party
	@param profile    the profile used for this party in this session
	@param protocol   the protocol used in this session
	@param progress   the {@link Progress} object used for this session
	@param parameters a {@link Map} &lt;String, Object&gt; containing
	                  initialization parameters for this party. The Object
	                  can be a HashMap, ArrayList, String, or number
	                  (Integer, Double, etc). The Object should not be just
	                  any Object because deserialization will work only with
	                   the mentioned types.
	'''
	if profile == None or protocol == None or \
		progress == None or parameters == None:
		raise ValueError(
			"party, profile, protocol, parameters and progress must be not None.")
	self._profile = profile;
	self._protocol = protocol;
	self._progress = progress;
	self._parameters = parameters;
	self._id = id;

	def getProfile(self) -> ProfileRef:
		'''
		@return the profile used for this party in this session
		'''
		return self._profile

	def getProtocol(self) -> ProtocolRef :
		return self._protocol
	

	def	getProgress() -> Progress :
		'''
		@return the {@link Progress} object used for this session
		'''
		return self._progress
	

	def getID(self) -> PartyId :
		'''
		@return the party ID of this party
		'''
		return self._id

	def getParameters(self)->Parameters  :
		'''
		@return a {@link HashMap}&lt;String,Object&gt; containing initialization
		        parameters that can be used by the party.
		'''
		return self._parameters

	def __str__(self)->str:
		return "Settings[" + self._id + "," + self._profile + "," + self._protocol + ","\
				+ self._progress + "," + self._parameters + "]"
	

